@@ -1,4 +1,5 @@
-/* Copyright 2000-2004 The Apache Software Foundation
+/* Copyright 2000-2005 The Apache Software Foundation or its licensors, as
+ * applicable.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -69,6 +70,10 @@
  *  Tolerates URLs that look like: <ldapurl> and <URL:ldapurl>
  */
 
+#include "apu.h"
+#include "apr_pools.h"
+#include "apr_general.h"
+#include "apr_strings.h"
 #include "apr_ldap.h"
 
 #if APR_HAS_LDAP
@@ -77,10 +82,6 @@
 #include <stdlib.h>
 #endif
 
-#include "apu.h"
-#include "apr_pools.h"
-#include "apr_strings.h"
-
 #ifndef LDAPS_PORT
 #define LDAPS_PORT              636  /* ldaps:/// default LDAP over TLS port */
 #endif
